#pragma once

#include <string>
#include <vector>

/*
* $Header: https://svn.mpia.de/gulli/geirs/src/trunk/extern/fits2fwhm/Fits2fwhm.h 798 2021-06-15 13:53:57Z mathar $
*/

/*!***********************************************
* @file
* @brief API declaration of the Fits2fwhm  class.
* @author Richard J. Mathar
*/

/*!*************************************
* @brief A one-time snapshot of an image from the buffer of the Patrol Camera.
* @since 2017-08-21
* @author Richard J. Mathar
*/
class Fits2fwhm
{

public:
	/*!*****************************
	* @brief pixel scale [deg/pix]
	*/
	float pxscal ;

	/*!**************************
	* @brief width of the frame to be chopped around input images.
	*  The main purpose is to remove pixels at the edges which are from overscan regions etc.
	*/
	int choppx ;

	/*!*************************
	* @brief primary header keyword providing the M2 focus positions
	*/
	std::string focpos ;

	/*!**************************
	* @brief flag for batch-type (non-GUI) operation
	*/
	bool batch ;

	/*!**************************
	* @brief a positive value (essentially >1) for a (relative) detection threshold
	*/
	float thresh ;

	Fits2fwhm(int chop, const std::string & fockw , bool bat, float thold) ;

	int run(int argc, char *argv[]) ;

	int chopFrame(const std::string & ifile, const std::string & ofile, int & bin, 
		float & pixscal, float & focparm) ;

	std::vector<float> centroids(const char *skfits, int bin, float pixscal) ;

	void ds9(const char * skfits, const std::vector<float> & x, const std::vector<float> & y, const std::vector<float> &w) const ;

protected:
	static int ftcopy(const char * infile, const char *outfile, int copyall) ;

private:

} ; /* Fits2fwhm */
