/*
* $Header: https://svn.mpia.de/gulli/geirs/src/trunk/extern/fits2fwhm/fits2fwhm.cxx 798 2021-06-15 13:53:57Z mathar $
*/

#include <string>
#include <iostream>
#include <cstdlib>
#include <unistd.h>

#include "Fits2fwhm.h"

using namespace std ;

void usage(char *argv0)
{
	cerr << "Usage: " << argv0 << " [-q] [-c pxNoChopframe] [-k hdrfockw] file.fits [file.fits ..]" << endl ;
	cerr << "Usage: " << argv0 << " [-q] [-c pxNoChopframe] [-t threshold] file.fits" << endl ;
}

/** Main function.
* One could try to reprogram everything in python: https://github.com/kbarbary/sep/blob/master/README.md
* @since 2021-03-01
*/
int main(int argc, char *argv[])
{
	/* batch job/quiet or interactive session?
	* Value can be changed using the -q option of the command line.
	*/
	bool quiet = false ;

	/* chop input fits files : remove a frame of that many pixels around the
	* images in the input files. The default of 150 is considered sufficient
	* to remove overscan and "bleading" edges of the King 70 cm telescope.
	* Value can be changed using the -c option of the command line.
	*/
	int chop = 150 ;

	/* name of the PHDU keyword with the T_FOCUS  value. This
	* is basically a CAHA default name.
	* Value can be changed using the -k option of the command line.
	*/
	string fockw("T_FOCUS") ;

	/* default detectrion threshold is 3
	*/
	float thold(3.0) ;

	/* command line option character
        */
        char oc;
        while (  (oc=getopt(argc,argv,"qc:k:t:")) != -1 )
        {
		switch(oc)
		{
		case 'q' :
			quiet = true ;
                        break ;
		case 'c' :
			chop = atoi(optarg) ;
			if ( chop < 0 )
			{
	                        cerr << "Error: invalid negative chop parameter " << optarg << endl ;
				return 1 ;
			}
                        break ;
		case 'k' :
			fockw = optarg ;
                        break ;
		case 't' :
			thold = atof(optarg) ;
                        break ;
		case '?' :
			cerr << "Warning: Unsupported command line option " << optopt << " ... ignored" << endl ;
			break ;
                }
        }

	Fits2fwhm task(chop,fockw,quiet,thold) ;

	if ( argc-optind <= 0)
	{
		cerr << "Error: no FITS files named on command line" << endl ;
		usage(argv[0]) ;
		return 1 ;
	}

	/* the main task is run by keeping the trailing command line arguments
	* (supposed to be one or more FITS file names) in the arguments list.
	*/
	task.run(argc-optind, argv+optind) ;
	return 0 ;
} /* main */
